import requests, json


def selectedProfileLinks(self, profileId, returnLimit=100):
    """
    Return all the profile links the profile ha

    Arguments:
        profileId -- User profile ID

        returnLimit -- The index and amount of results to return, if not provided is defaulted to 0 and 100

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileID": profileId,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileLink/Selected/",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def pageProfileLinks(self, templateType, moduleId, returnLimit=100):
    """
    Gets all the profiles linked to a Content Page

    Arguments:
        templateType -- The templateType of the page

        moduleId -- The moduleId of the page

        returnLimit -- The index and amount of results to return, if not provided is defaulted to 0 and 100

    Returns:
        Pagination response and list of profile objects
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "moduleId": moduleId,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileLink/Page/",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def selectProfileLink(self, profileId, link):
    """
    Allows you to select a link for a profile

    Arguments:
        profileId -- User profile ID

        link -- The link you wish to select

        e.g.

        {
            "templateType":"session",
            "moduleId":1
        }

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileID": profileId,
        "link": link,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileLink/Select/",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def multiSelectProfileLinks(self, profiles):
    """
    Allows you to select multiple pages on multiple profiles at once

    Arguments:
        profiles-- 	A list of profile references with link objects within. Refer to the example JSON

        e.g.

        [{
            "profileId":"ff11c742-346e-4874-9e24-efe6980a7453",
            "links":[
            {
                "templateType":"sesSiOn",
                "moduleId":1
            },
            {
                "templateType":"sesSiOn",
                "moduleId":2
            },
            {
                "templateType":"sesSiOn",
                "moduleId":3
            }]
        },
        {
            "profileId":"3e7026f6-cb67-452b-b962-125731807855",
            "links":[
            {
                "templateType":"sesSiOn",
                "moduleId":4
            },
            {
                "templateType":"sesSiOn",
                "moduleId":2
            },
            {
                "templateType":"sesSiOn",
                "moduleId":3
            }]
        }]

    Returns:
        Base response object
    """
    data = {"projectId": self.projectID, "apiKey": self.getKey(), "profiles": profiles}

    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileLink/MultiSelect/",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def deSelectProfileLinks(self, profileId, link):
    """
    Allows you to deselect a link for a profile

    Arguments:
        profileId -- The profileId of the profile

        link -- The link you wish to select

        e.g.

        {
            "templateType":"session",
            "moduleId":1
        }

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileId": profileId,
        "link": link,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileLink/Deselect/",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def clearProfileLinks(self, profileId, templateType):
    """
    Allows you to clear all the selected links of a templateType on a single profile

    Arguments:
        profileId -- The profileId of the profile

        templateType -- The templateType to clear links of

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileId": profileId,
        "templateType": templateType,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileLink/Clear/",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



import requests, json, os, sys

sys.path.append(os.path.dirname(__file__))
from icons import icon


def addDocuments(self, templateType, moduleId, fileDocuments):
    """
    Return all user profiles

    Arguments:
        templateType -- The template type of the page you're adding the documents to

        moduleId -- The moduleId of the page you're adding the documents to

        fileDocuments -- The file documents you want to add

        e.g.

        [
            {
                "name":"Power Point",
                "externalReference":"document-56454",
                "icon":icon["Film Reel"],
                "fileUrl":"https://example.org/powerpoints/session/44444/powerpoint.ppt"
            },
            {
                "name":"Demonstration Video",
                "externalReference":"document-56455",
                "icon":icon["Film Reel"],
                "fileUrl":"https://example.org/powerpoints/session/44444/demonstrationvideo.mp4"
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "moduleId": moduleId,
        "fileDocuments": fileDocuments,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/Document/AddFile",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def addExternalContentDocuments(self, templateType, moduleId, externalContentItems):
    """
    Return all user profiles

    Arguments:
        templateType -- The template type of the page you're adding the documents to

        moduleId -- The moduleId of the page you're adding the documents to

        externalContentItems -- The external content documents you want to add

        e.g.

        [
            {
                "name": "Test External Content",
                "icon": 69,
                "externalReference": "ext_content",
                "fileUrl": "https://www.youtube.com/watch?v=ieWm9T_GgSA",
                "type": "YouTube"
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "moduleId": moduleId,
        "externalContentItems": externalContentItems,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/Document/AddExternalContent",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



import requests, json


def addProfilePayment(self, profileId, paymentInfo):
    """
    Return all the profile links the profile ha

    Arguments:
        profileId -- User profile ID

        paymentInfo -- All payment information in JSON format

        e.g.

        {
            "amount": 1000,
            "amountTax": 100,
            "amountTaxRate": 0.1,
            "currency": "JPY",
            "platformFee": 30,
            "platformFeeTax": 3,
            "platformFeeTaxRate": 0.1,
            "platformFeeInvoiceDate": "2021-04-21 10:06:00",
            "gateway": "Stripe",
            "gatewayAccountId": "StripeAccount",
            "transactionId": "123456789",
            "method": "CreditCard",
            "status": "Paid"
        }

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileID": profileId,
    }
    data.update(paymentInfo)

    resp = requests.post(
        self.APIEndpoint + "/v2/ProfilePayment/Add/",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



import requests, json


def externalAuthentication(
    self, profileID: str, deviceID: str, requestVersion: int = 1
):
    """
    Authenticate a user's login via an external system

    Arguments:
        profileID -- The profile ID of the user

        deviceID -- The device ID of the user's device

        requestVersion -- The version of the request (default 1)
    Returns:
        firstLogin (bool) -- Indicates whether this is the first time this profile has logged into the Entegy system
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileId": profileID,
        "deviceId": deviceID,
        "requestVersion": requestVersion,
    }
    resp = requests.post(
        self.APIEndpoint + "/v2/Authentication/ExternalProfile",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



# Refer to document icons by their name rather than by number
icon = {
    "Document": 0,
    "Facebook": 1,
    "Linked In": 2,
    "Twitter": 3,
    "Map Pin": 4,
    "Globe": 5,
    "Enevelope": 6,
    "Phone": 7,
    "Speaker": 8,
    "Film Reel": 9,
    "Desktop": 10,
    "Chat": 11,
    "Map": 12,
    "Article": 13,
    "Gallery": 14,
    "Outbox": 15,
    "Linked In": 16,
    "Pin": 17,
    "Bar Graph": 18,
    "Paper Clip": 19,
    "Access Point": 20,
    "Calendar": 21,
    "Checkmark": 22,
    "Paper Plane": 23,
    "Star": 24,
    "Warning Triangle": 25,
    "Search": 26,
    "Folder": 27,
    "Inbox": 28,
    "Edit": 31,
    "People": 32,
    "Home": 37,
    "Home Search": 38,
    "Diner": 39,
    "Open Sign": 40,
    "Info Circle": 41,
    "Help Circle": 42,
    "Flag": 43,
    "Wine Glass": 44,
    "Cocktail": 45,
    "Coffee": 46,
    "News": 47,
    "Car": 48,
    "Office Building": 49,
    "Info Square": 52,
    "Globe Search": 53,
    "Alarm Clock": 54,
    "Guitar": 55,
    "Road Signs": 56,
    "Wifi Tablet": 57,
    "Open Book": 58,
    "X Box": 62,
    "Gear": 64,
    "Log out": 65,
    "Instagram": 68,
    "Google Plus": 69,
    "Hashtag": 70,
    "Back": 71,
    "Forward": 72,
    "Refresh": 73,
    "Document Stamp": 75,
    "Alarm Bell": 77,
    "Alarm Bell Cog": 78,
}



import requests, json


def getProfileCustom(self, key):
    """
    This request will get a single custom field

    Arguments:
        key -- The key of the custom field to return

    Returns:
        The requested customField object"""

    data = {"projectId": self.projectID, "apiKey": self.getKey(), "key": key}
    print(data)
    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileCustomField",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def createProfileCustom(self, customField):
    """
    Creates a new Custom Field for Profiles.

    There is a limited number of text custom fields allowed per project. Once a custom field is created, it's type cannot be modified.

    Arguments:
        customField -- The custom field you wish to create

        e.g.

        {
            "key":"dietary-requirements",
            "name":"Dietary requirements",
            "type":"MultiChoice",
            "options":[
                {
                    "name":"Halal"
                },
                {
                    "name":"Vegan"
                },
                {
                    "name":"Lactose Intolerant"
                },
                {
                    "name":"Gluten Intolerant"
                }
            ]
        }

    Returns:
        Base response object"""

    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "customField": customField,
    }
    print(data)
    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileCustomField/Create",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def updateProfileCustom(self, key, customField):
    """
    Update custom profile 'key' with 'customField' data

    Arguments:
        key -- The key of the custom field to return

        customField -- The data to update the field with

        e.g.

        {
            "options":[
                {
                    "optionId": 6,
                    "name":""
                },
                {
                    "optionId": 7,
                    "name":"Halal"
                },
                {
                    "optionId": 8,
                    "name":"Vegan"
                },
                {
                    "name":"Lactose Intolerant"
                },
                {
                    "name":"Gluten Intolerant"
                }
            ]
        }

    Returns:
        The requested customField object"""

    data = {"projectId": self.projectID, "apiKey": self.getKey(), "key": key}
    print(data)
    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileCustomField/Update",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def deleteProfileCustom(self, key):
    """
    This request will delete a single custom field

    Arguments:
        key -- The key of the custom field to delete

    Returns:
        Base response object"""

    data = {"projectId": self.projectID, "apiKey": self.getKey(), "key": key}
    print(data)
    resp = requests.delete(
        self.APIEndpoint + "/v2/ProfileCustomField/Delete",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def allProfileCustom(self):
    """
    This request will return all custom fields

    Returns:
        List of all customFields"""

    data = {"projectId": self.projectID, "apiKey": self.getKey()}
    print(data)
    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileCustomField/All",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



import requests, json

from Content.content import updateContent


def getMultiLinks(self, templateType, moduleId=None, externalReference=None):
    """
    Returns all the multi links associated with the content page

    Arguments:
        templateType -- The template type of the page you want

        moduleId -- The moduleId of the page you want

    Returns:
        The multi links the content page has
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
    }
    if moduleId != None:
        data.update({"moduleId": moduleId})
    if externalReference != None:
        data.update({"externalReference": externalReference})

    resp = requests.post(
        self.APIEndpoint + "/v2/MultiLink", headers=self.headers, data=json.dumps(data)
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def addMultiLinks(
    self, templateType, multiLinks, moduleId=None, externalReference=None
):
    """
    Add multi links to a content page.

    Arguments:
        templateType -- The template type of the page you want to add links to

        moduleId -- The moduleId of the page you want to add links to

        multiLinks -- The links you want to add

        e.g.

        [
            {
                "templateType":"Speaker",
                "moduleId":1
            },
            {
                "templateType":"Speaker",
                "externalReference":"au-speaker-1546895"
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "multiLinks": multiLinks,
    }
    if moduleId != None:
        data.update({"moduleId": moduleId})
    if externalReference != None:
        data.update({"externalReference": externalReference})
    resp = requests.post(
        self.APIEndpoint + "/v2/MultiLink/Add",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def removeMultiLink(
    self,
    templateType,
    targetTemplateType,
    moduleId=None,
    externalReference=None,
    targetModuleId=None,
    targetExternalReference=None,
):
    """
    Removes a single multi link from a page

    Arguments:
        templateType -- The template type of the page you want to remove links from

        moduleId -- The moduleId of the page you want to remove links from

        targetTemplateType -- The template type of the multi link you want to remove

        targetModuleId -- The moduleId of the multi link you want to remove

        e.g.

        [
            {
                "templateType":"Speaker",
                "moduleId":1
            },
            {
                "templateType":"Speaker",
                "externalReference":"au-speaker-1546895"
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "targetTemplateType": targetTemplateType,
    }
    if moduleId != None:
        data.update({"moduleId": moduleId})
    if externalReference != None:
        data.update({"externalReference": externalReference})
    if targetExternalReference != None:
        data.update({"targetExternalReference": targetExternalReference})
    if targetModuleId != None:
        data.update({"targetModuleId": targetModuleId})
    resp = requests.post(
        self.APIEndpoint + "/v2/MultiLink/Remove",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def removeAllMultiLinks(
    self, templateType, moduleId=None, externalReference=None, linkTemplateType=None
):
    """
    Removes all the multi links from a page

    Arguments:
        templateType -- The template type of the page you want to remove links from

        moduleId -- The moduleId of the page you want to remove links from

        linkTemplateType -- The template type of the multi links you want to remove

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
    }

    if moduleId != None:
        data.update({"moduleId": moduleId})
    if externalReference != None:
        data.update({"externalReference": externalReference})

    if linkTemplateType != None:
        updateData = {"linkTemplateType": linkTemplateType}
        data.update(updateData)

    resp = requests.post(
        self.APIEndpoint + "/v2/MultiLink/RemoveAll",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



import requests, json


def awardPoints(
    self,
    pointEvent: str,
    points: int,
    userID="",
    externalReference=None,
    badgeReference=None,
    internalReference=None,
):

    """
    Give points to a profile

    Arguments:
        pointEvent -- The types of points you're assigning (https://situ.entegysuite.com.au/Docs/Api/point-constants#pointtypes)
        points -- The amount of points you're assigning
        userID -- User profile ID

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileId": userID,
        "pointEvent": pointEvent,
        "points": points,
    }

    if externalReference != None:
        data.update({"externalReference": userID})
    if badgeReference != None:
        data.update({"badgeReference": userID})
    if internalReference != None:
        data.update({"internalReference": userID})

    resp = requests.post(
        self.APIEndpoint + "/v2/Point/Award",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def getPoints(
    self, userID="", externalReference=None, badgeReference=None, internalReference=None
):

    """
    Get the amount of points a profile has

    Arguments:
        userID -- User profile ID

    Returns:
        Base response object
    """
    data = {"projectId": self.projectID, "apiKey": self.getKey(), "profileId": userID}

    if externalReference != None:
        data.update({"externalReference": userID})
    if badgeReference != None:
        data.update({"badgeReference": userID})
    if internalReference != None:
        data.update({"internalReference": userID})

    resp = requests.post(
        self.APIEndpoint + "/v2/Point/Earned",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def getPointLeaderboard(self):

    """
    Get the entire leaderboard for the given project

    Returns:
        Leaderboard object
    """
    data = {"projectId": self.projectID, "apiKey": self.getKey()}

    resp = requests.post(
        self.APIEndpoint + "/v2/Point/Leaderboard",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



import requests, json


def getContent(
    self,
    templateType,
    moduleId=None,
    externalReference=None,
    includeCategories=False,
    includeDocuments=False,
    includeLinks=False,
    includeMultiLinks=False,
    includePageSettings=False,
):
    """
    Return all user profiles

    Arguments:
        templateType -- The type of the template you want content from

        moduleId -- The moduleId of the page you want content from

    Returns:
        The content response differs depending on what type of content you request.
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "includeCategories": includeCategories,
        "includeDocuments": includeDocuments,
        "includeLinks": includeLinks,
        "includeMultiLinks": includeMultiLinks,
        "includePageSettings": includePageSettings,
    }
    if moduleId != None:
        data.update({"moduleId": moduleId})
    if externalReference != None:
        data.update({"externalReference": externalReference})
    resp = requests.post(
        self.APIEndpoint + "/v2/Content", headers=self.headers, data=json.dumps(data)
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def getScheduleContent(
    self,
    moduleId=None,
    externalReference=None,
    includeCategories=False,
    includeDocuments=False,
    includeLinks=False,
    includeMultiLinks=False,
    includePageSettings=False,
):
    """
    Returns an entire schedule.

    Arguments:
        moduleId -- Any parameters to filter the returned profile by

    Returns:
        Content Schedule object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "includeCategories": includeCategories,
        "includeDocuments": includeDocuments,
        "includeLinks": includeLinks,
        "includeMultiLinks": includeMultiLinks,
        "includePageSettings": includePageSettings,
        "moduleId": moduleId,
    }
    if externalReference != None:
        data.update({"externalReference": externalReference})
    resp = requests.post(
        self.APIEndpoint + "/v2/Content/Schedule",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def createContent(self, content, contentGroup="Default"):
    """
    Creates a root content item. You can only create Template Types that are listed as root content.

    Arguments:
        content -- The content you are creating, supports templateType, name, mainImage and externalReference

        e.g.

        {
            "templateType":"Schedule",
            "name":"Conference Program",
            "externalReference":""
        }

        moduleId -- The content group in the core this new root content should go in, leave blank for default

    Returns:
        The moduleId of the page you just created
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "contentGroup": contentGroup,
        "content": content,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/Content/Create",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def addChildrenContent(
    self,
    templateType,
    childTemplateType,
    children,
    moduleId=None,
    externalReference=None,
):
    """
    Adds children to templateType

    Arguments:
        templateType -- The template type the children are being added to

        moduleId -- The name for the page

        childTemplateType -- The templateType for the children you're creating

        children -- The page data you want to add to the root templateType

        e.g.

        [
            {
                "externalReference":"au-speaker-545415842",
                "name":"John Smith",
                "strings":
                    {
                        "copy":"John Smith is an expert on many fields. He holds many prestigious awards from many prestigious parties",
                        "companyAndPosition":"XYZ Widgets // Director"
                    },
                "category":3,
                "sortOrder" : 4
            },
            {
                "externalReference":"au-speaker-874561246",
                "name":"John Doe",
                "strings":
                    {
                        "copy":"John Doe is an expert on many fields. He holds many prestigious awards from many prestigious parties",
                        "companyAndPosition":"ACME Corp // Director",
                        "phoneNumber":"1300 123 456",
                        "emailAddress":"john.doe@acme.corp",
                        "website":"https://acme.corp",
                        "address":"123 Acme Street
                                Corporation Town 1234
                                Australia"
                    },
                "category":2,
                "sortOrder" : 5
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "childTemplateType": childTemplateType,
        "children": children,
    }
    if moduleId != None:
        data.update({"moduleId": moduleId})
    if externalReference != None:
        data.update({"externalReference": externalReference})

    resp = requests.post(
        self.APIEndpoint + "/v2/Content/AddChildren",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def updateContent(self, templateType, content, moduleId=None, externalReference=None):
    """
    Updates data within a content item

    Arguments:
        templateType -- The templateType you're updating

        moduleId -- The moduleId of the page you're updating

        content -- The content you're updating, supports the name, sort order, mainImage, strings and links

        e.g.

        {
            "name":"Mr John Smith",
            "sortOrder":1
            "strings":
                {
                    "copy":"Mr John Smith is an expert on many fields. He holds many prestigious awards from many prestigious parties",
                    "companyAndPosition":"XYZ Widgets || Director"
                }
        }

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "content": content,
    }
    if moduleId != None:
        data.update({"moduleId": moduleId})
    if externalReference != None:
        data.update({"externalReference": externalReference})

    resp = requests.post(
        self.APIEndpoint + "/v2/Content/Update",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def deleteContent(self, templateType, moduleId=None, externalReference=None):
    """
    Allows you to delete a content resource from the Entegy System. Any content deleted is unrecoverable.

    -= WARNING =- Deleting root content will result in all child pages being deleted!

    Arguments:
        templateType -- The templateType of the resource you're deleting

        moduleId -- The moduleId of the page you're deleting

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
    }
    if moduleId != None:
        data.update({"moduleId": moduleId})
    if externalReference != None:
        data.update({"externalReference": externalReference})

    resp = requests.delete(
        self.APIEndpoint + "/v2/Content/Delete",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



import requests, json


def allProfiles(self, returnLimit=100, params={}):
    """
    Return all user profiles

    Arguments:
        returnLimit -- The index and amount of results to return, if not provided is defaulted to 0 and 100

        params -- Any parameters to filter the returned profile by

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "pagination": {"start": 0, "limit": returnLimit},
    }

    data.update(params)

    resp = requests.post(
        self.APIEndpoint + "/v2/Profile/All",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def getProfile(
    self,
    userID="",
    externalReference=None,
    badgeReference=None,
    internalReference=None,
    params={},
):
    """
    Get user profile from ID

    Arguments:
        userID -- User profile ID

        params -- Any parameters to filter the returned profile by

    Returns:
        User profile JSON output
    """
    data = {"projectId": self.projectID, "apiKey": self.getKey(), "profileId": userID}
    if externalReference != None:
        data.update({"externalReference": externalReference})
    if badgeReference != None:
        data.update({"badgeReference": badgeReference})
    if internalReference != None:
        data.update({"internalReference": internalReference})

    data.update(params)

    resp = requests.post(
        self.APIEndpoint + "/v2/Profile/", headers=self.headers, data=json.dumps(data)
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def deleteProfile(self, userID):
    """
    Delete user profile from ID

    Arguments:
        userID -- User profile ID

    Returns:
        Base response object
    """
    data = {"projectId": self.projectID, "apiKey": self.getKey(), "profileId": userID}

    resp = requests.delete(
        self.APIEndpoint + "/v2/Profile/Delete",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def createProfile(self, profileObject):
    """
    Create user profile from profile JSON object

    Arguments:
        profileObject -- User profile JSON object
        e.g.
        {
            "externalReference":"au-prf-31242354253",
            "firstName":"John",
            "lastName":"Smith",
            "type":"Attendee"
            /* rest of profile object (all extra fields are optional)*/
        }

    Returns:
        Reponse code, success/error message, and profileID in JSON format"""

    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profile": profileObject,
    }
    resp = requests.post(
        self.APIEndpoint + "/v2/Profile/Create",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def updateProfile(self, profileID, profileObject):
    """
    Update user profile from profile JSON object

    Arguments:
        profileID -- User profile ID to update

        profileObject -- User profile JSON object
        e.g.
        {
            "firstName":"Fred",
            "imageUrl":"https://images.example.org/profileimages/fredsmith/image.png"
        }

    Returns:
        Base response object"""

    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileID": profileID,
        "profile": profileObject,
    }
    resp = requests.post(
        self.APIEndpoint + "/v2/Profile/Update",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def syncProfiles(self, updateReferenceType, profiles, groupByFirstProfile=False):
    """
    Sync user profiles with reference to updateReferenceType

    Arguments:
        updateReferenceType -- The identifier to use to match profiles for updating. profileId, internalReference, externalReference, badgeReference

        profiles -- The list of profiles you want to create or update
        e.g.
        [
            {
                "profileId": "ff11c742-346e-4874-9e24-efe6980a7453",
                "customFields":
                {
                    "favourite-Food": "Pizza",
                    "water-Preference": "Cold Water"
                }
            },
            {
                "profileId": "4255a414-d95c-4106-a988-d0e10947ede5",
                "customFields":
                {
                    "favourite-Food": "Pizza",
                    "water-Preference": "Cold Water"
                }
            },
            {
                "firstName": "Test",
                "lastName": "User",
                "type": "attendee",
                "customFields":
                {
                    "favourite-Food": "Pizza",
                    "water-Preference": "Cold Water"
                }
            }
        ]

    groupByFirstProfile	-- If true the parent profile of all profiles in this sync will be set to the first profile in the profiles list (except the first profile itself, which will be set to have no parent)

    Returns:
        This endpoint returns a base response with an array of specific profile results in the same input order as the request"""

    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "updateReferenceType": updateReferenceType,
        "profiles": profiles,
    }
    resp = requests.post(
        self.APIEndpoint + "/v2/Profile/Sync",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def sendWelcomeEmail(self, profileID):
    """
    Re-sends the welcome email for a given profile on a given project

    Arguments:
        profileID -- The profileId of the profile you want to update

    Returns:
        Base response object"""

    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileID": profileID,
    }
    resp = requests.post(
        self.APIEndpoint + "/v2/Profile/SendWelcomeEmail",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



from random import randint
import requests
import json
import sys
import os
from requests.structures import CaseInsensitiveDict

sys.path.append(os.path.dirname(__file__))
from .Profiles.profileCustom import deleteProfileCustom

APIEndpoints = {
    "AU": "https://api.entegy.com.au",
    "US": "https://api-us.entegy.com.au",
    "EU": "https://api-eu.entegy.com.au",
}

# API Constructor
class EntegyAPI:

    # Public variables
    apiKey = ""
    apiSecret = ""
    projectID = ""
    headers = CaseInsensitiveDict()
    APIEndpoint = ""

    # Import methods

    # Profiles
    from .Profiles.profiles import (
        allProfiles,
        createProfile,
        getProfile,
        deleteProfile,
        updateProfile,
        syncProfiles,
        sendWelcomeEmail,
    )
    from .Profiles.profileTypes import (
        getProfileType,
        createProfileType,
        updateProfileType,
        deleteProfileType,
        allProfileTypes,
    )
    from .Profiles.profileCustom import (
        getProfileCustom,
        createProfileCustom,
        updateProfileCustom,
        deleteProfileCustom,
        allProfileCustom,
    )
    from .Profiles.profileLinks import (
        selectedProfileLinks,
        pageProfileLinks,
        selectProfileLink,
        multiSelectProfileLinks,
        deSelectProfileLinks,
        clearProfileLinks,
    )
    from .Profiles.profilePayments import addProfilePayment

    # Content
    from .Content.content import (
        getContent,
        getScheduleContent,
        createContent,
        addChildrenContent,
        updateContent,
        deleteContent,
    )
    from .Content.categories import (
        availableCategories,
        selectCategories,
        deselectCategories,
        createCategories,
        createChildCategories,
        updateCategories,
        deleteCategories,
    )
    from .Content.documents import addDocuments, addExternalContentDocuments
    from .Content.multiLink import (
        getMultiLinks,
        addMultiLinks,
        removeMultiLink,
        removeAllMultiLinks,
    )

    # Points
    from .Points.pointManagement import awardPoints, getPointLeaderboard, getPoints

    # Plugins
    from .Plugins.extAuth import externalAuthentication

    # Contruct api class with given params
    def __init__(self, apiKey, apiSecret, projectID, region="AU"):
        """
        Contruct an EntegyAPI wrapper

        Arguments:
            apiKey -- Entegy API key (Can either be a string, or an array of strings)

            apiSecret -- Entegy API secret key (Can either be a string, or an array of strings the same size as apiKey)

            projectID -- Entegy project ID

            region -- 'AU', 'US', 'EU' (Default = 'AU')
        """

        # If multiple API keys were given, ensure that equal amounts of each were given
        if isinstance(self.apiKey, list):
            if len(self.apiKey) != len(self.apiSecret):
                raise IndexError(
                    "Invalid amount of API Keys to Secrets. Number of each must be equal!"
                )

        # Set public variables
        self.apiKey = apiKey
        self.apiSecret = apiSecret
        self.projectID = projectID

        # Set API header
        self.headers["Content-Type"] = "application/json"

        # Set API endpoint
        self.APIEndpoint = APIEndpoints[region]

    def getKey(self):
        """Return API Key

        Returns:
            string: API Key
        """
        # If the initially provided key was not an array, return `self.apiKey`
        if not isinstance(self.apiKey, list):
            self.headers["Authorization"] = f"ApiKey {self.apiSecret}"
            return self.apiKey

        randKeyNum = randint(0, len(self.apiKey) - 1)

        self.headers["Authorization"] = f"ApiKey {self.apiSecret[randKeyNum]}"
        return self.apiKey[randKeyNum]

    def getEndpoint(self):
        """
        Returns:
        API endpoint URL
        """
        return self.APIEndpoint



import requests, json


def getProfileType(self, name):
    """
    This request will get a single profile type

    Arguments:
        name -- The name of the profile type

    Returns:
        The requested profile"""

    data = {"projectId": self.projectID, "apiKey": self.getKey(), "name": name}
    print(data)
    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileType",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def createProfileType(self, profileType):
    """
    Creates a ProfileType with the data passed in the profileType

    Arguments:
        profileType -- The data for the profile type you're creating

        e.g.
        {
            "name":"Exhibitor",
            "externalReference":"au-ref-tickettype-564545"
        }

    Returns:
        Base response object"""

    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "profileType": profileType,
    }
    print(data)
    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileType/Create",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def updateProfileType(self, name, profileType):
    """
    Updates the ProfileType with the data passed in the profileType

    Arguments:
        name -- The name of the profile type

        profileType -- The data you wish to update

        e.g.

        {
            "externalReference":"au-ref-tickettype-564545"
        }

    Returns:
        Base response object"""

    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "name": name,
        "profileType": profileType,
    }
    print(data)
    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileType/Update",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def deleteProfileType(self, name):
    """
    Deletes a profile type. The type cannot be in use.

    Arguments:
        name -- The name of the profile type

    Returns:
        Base response object"""

    data = {"projectId": self.projectID, "apiKey": self.getKey(), "name": name}
    print(data)
    resp = requests.delete(
        self.APIEndpoint + "/v2/ProfileType/Delete",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def allProfileTypes(self):
    """
    This request will get all profile types

    Returns:
        All profileTypes"""

    data = {"projectId": self.projectID, "apiKey": self.getKey()}
    print(data)
    resp = requests.post(
        self.APIEndpoint + "/v2/ProfileType/All",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output



import requests, json


def availableCategories(self, templateType, moduleId):
    """
    This returns a list of the available categories for the page in question.

    Arguments:
        templateType -- The template type of the page you want

        moduleId -- 	The moduleId of the page you want

    Returns:
        List of available categories
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "moduleId": moduleId,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/Categories/Available",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def selectCategories(self, templateType, moduleId, categories):
    """
    Allows you to select multiple categories of a template type

    Arguments:
        templateType -- The template type of the page you want

        moduleId -- 	The moduleId of the page you want

        categories -- The categories you want to select

        e.g.

        [
            {
                "name":"Keynote",
            },
            {
                "externalReference":"plenary"
            },
            {
                "moduleId":5,
            },
            {
                "name":"Panel",
            },
            {
                "externalReference":"chair"
            },
            {
                "moduleId":6
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "moduleId": moduleId,
        "categories": categories,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/Categories/Select",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def deselectCategories(self, templateType, moduleId, categories):
    """
    You can unselect a category with either an externalReference or moduleId.

    Arguments:
        templateType -- The template type of the page you want

        moduleId -- 	The moduleId of the page you want

        categories -- The categories you want to select

        e.g.

        [
            {
                "name":"Keynote",
            },
            {
                "externalReference":"plenary"
            },
            {
                "moduleId":5,
            },
            {
                "name":"Panel",
            },
            {
                "externalReference":"chair"
            },
            {
                "moduleId":6
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "moduleId": moduleId,
        "categories": categories,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/Categories/Deselect",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def createCategories(self, templateType, moduleId, categories):
    """
    Allows you to create categories under a root page.

    Arguments:
        templateType -- The template type of the page you want

        moduleId -- 	The moduleId of the page you want

        categories -- The categories you want to select

        e.g.

        [
            {
                "name":"Keynote",
                "externalReference":"keynote"
            },
            {
                "name":"Plenary",
                "externalReference":"plenary"
            },
            {
                "name":"Breakout",
                "externalReference":"breakout"
            },
            {
                "name":"Panel",
                "externalReference":"panel"
            },
            {
                "name":"Chair",
                "externalReference":"chair"
            },
            {
                "name":"Sponsored",
                "externalReference":"sponsored"
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "moduleId": moduleId,
        "categories": categories,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/Categories/Create",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def createChildCategories(self, templateType, externalReference, categories):
    """
    Allows you to create categories under another category.

    Arguments:
        templateType -- The template type of the page you want

        externalReference -- The externalReference of the page you want

        categories -- The categories you want to select

        e.g.

        [
            {
                "name":"Stream 1",
                "externalReference":"stream1"
            },
            {
                "name":"Stream 2",
                "externalReference":"stream2"
            },
            {
                "name":"Stream 3",
                "externalReference":"stream3"
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "externalReference": externalReference,
        "categories": categories,
    }

    resp = requests.post(
        self.APIEndpoint + "/v2/Categories/CreateChild",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def updateCategories(self, moduleId, name):
    """
    Allows you to change the name of a category.

    Arguments:
        moduleId -- The moduleId of the category

        name -- The new name of the category

    Returns:
        Base response object
    """
    data = {"projectId": self.projectID, "moduleId": moduleId, "name": name}

    resp = requests.post(
        self.APIEndpoint + "/v2/Categories/Update",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output


def deleteCategories(self, templateType, moduleId, categories):
    """
    Allows you to create categories under another category.

    Arguments:
        templateType -- The template type of the page you want

        moduleId -- The moduleId of the page you want

        categories -- The categories you want to select

        e.g.

        [
            {
                "externalReference":"plenary"
            },
            {
                "moduleId":5,
            },
            {
                "externalReference":"chair"
            },
            {
                "moduleId":6
            }
        ]

    Returns:
        Base response object
    """
    data = {
        "projectId": self.projectID,
        "apiKey": self.getKey(),
        "templateType": templateType,
        "moduleId": moduleId,
        "categories": categories,
    }

    resp = requests.delete(
        self.APIEndpoint + "/v2/Categories/Delete",
        headers=self.headers,
        data=json.dumps(data),
    )
    if resp == None:
        raise Exception("No reponse received from API")
    output = resp.json()
    return output
